function [A, b] = guidedfilter(I_guidance, I_input, radius, eps, sampling, weights)
% O(1) time implementation of guided filter according to He et al.

    if nargin < 5
        % Subsampling factor for fast guided filter.
        sampling = 1;
    end
    if nargin < 6
        weights = ones(size(I_input));
    end
    
    if sampling ~= 1
        % Resampling of input and guidance image for fast guided filtering.
        inSize = size(I_input);
        I_guidance = imresize(I_guidance, 1/sampling);
        I_input = imresize(I_input, 1/sampling);
        weights = imresize(weights, 1/sampling);
        % Set the filter radius according to the given resampling factor.
        radius = max([round(radius / sampling) 1]);
    end
    
    % Truncate small confidence weights to avoid numerical instabilities.
    minWeight = 1e-1;
    weights(weights <= minWeight) = minWeight;
    N = boxfilter(weights, radius);
    
    % Compute mean and covariances using the boxfilter.
    mean_guidance = boxfilter(weights .* I_guidance, radius) ./ N;
    mean_input = boxfilter(weights .* I_input, radius) ./ N;
    mean_Ip = boxfilter(weights .* (I_guidance.*I_input), radius) ./ N;
    cov_Ip = mean_Ip - mean_guidance .* mean_input;
    mean_II = boxfilter(weights .* (I_guidance.*I_guidance), radius) ./ N;
    var_I = mean_II - mean_guidance .* mean_guidance;

    % Compute coefficients for the patches.
    A = cov_Ip ./ (var_I + eps); 
    b = mean_input - A .* mean_guidance; 

    % Compute mean of all coefficients per patch using the boxfilter..
    A = boxfilter(weights .* A, radius) ./ N;
    b = boxfilter(weights .* b, radius) ./ N;
    
    if sampling ~= 1
        % Upsampling if fast guided filtering was used.
        A = imresize(A, inSize);
        b = imresize(b, inSize);
    end